@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 """
+2020-09-07 Cornelius Kölbel <cornelius.koelbel@netknights.it>
+           Add exception
 2017-04-26 Friedrich Weber <friedrich.weber@netknights.it>
            Make it possible to check for correct LDAPS/STARTTLS settings
 2017-01-08 Cornelius Kölbel <cornelius.koelbel@netknights.it>
@@ -47,16 +49,10 @@ from ldap3.utils.conv import escape_bytes
 import ldap3
 import re
 import pyparsing
-import six
 
-try:
-    from six import cStringIO as BufferIO
-except ImportError:
-    from six import StringIO as BufferIO
+from .smtpmock import get_wrapped
 
-import inspect
 from collections import namedtuple, Sequence, Sized
-from functools import update_wrapper
 from privacyidea.lib.utils import to_bytes, to_unicode
 
 DIRECTORY = "tests/testdata/tmp_directory"
@@ -76,30 +72,6 @@ def _convert_objectGUID(item):
     return item
 
 
-def get_wrapped(func, wrapper_template, evaldict):
-    # Preserve the argspec for the wrapped function so that testing
-    # tools such as pytest can continue to use their fixture injection.
-    args, a, kw, defaults = inspect.getargspec(func)
-    values = args[-len(defaults):] if defaults else None
-
-    signature = inspect.formatargspec(args, a, kw, defaults)
-    is_bound_method = hasattr(func, '__self__')
-    if is_bound_method:
-        args = args[1:]     # Omit 'self'
-    callargs = inspect.formatargspec(args, a, kw, values,
-                                     formatvalue=lambda v: '=' + v)
-
-    ctx = {'signature': signature, 'funcargs': callargs}
-    six.exec_(wrapper_template % ctx, evaldict)
-
-    wrapper = evaldict['wrapper']
-
-    update_wrapper(wrapper, func)
-    if is_bound_method:
-        wrapper = wrapper.__get__(func.__self__, type(func.__self__))
-    return wrapper
-
-
 class CallList(Sequence, Sized):
     def __init__(self):
         self._calls = []
@@ -688,6 +660,7 @@ class Ldap3Mock(object):
         self._calls = CallList()
         self._server_mock = None
         self.directory = []
+        self.exception = None
         self.reset()
 
     def reset(self):
@@ -704,6 +677,9 @@ class Ldap3Mock(object):
             except OSError as e:
                 raise
 
+    def set_exception(self, exc=True):
+        self.exception = exc
+
     def _load_data(self, directory):
         try:
             with open(directory, 'r') as f:
@@ -747,6 +723,9 @@ class Ldap3Mock(object):
         and object
             response
         """
+        # Raise an exception, if we are told to do so
+        if self.exception:
+            raise Exception("LDAP request failed")
         # check the password
         correct_password = False
         # Anonymous bind
