@@ -9,6 +9,7 @@ lib/event.py (the decorator)
 
 import responses
 import os
+import mock
 
 from privacyidea.lib.eventhandler.usernotification import UserNotificationEventHandler
 from .base import MyTestCase, FakeFlaskG, FakeAudit
@@ -22,6 +23,7 @@ from privacyidea.models import EventCounter
 from privacyidea.lib.eventhandler.federationhandler import FederationEventHandler
 from privacyidea.lib.eventhandler.requestmangler import RequestManglerEventHandler
 from privacyidea.lib.eventhandler.base import BaseEventHandler, CONDITION
+from privacyidea.lib.counter import increase as counter_increase
 from flask import Request
 from werkzeug.test import EnvironBuilder
 from privacyidea.lib.event import (delete_event, set_event,
@@ -272,6 +274,36 @@ class BaseEventHandlerTestCase(MyTestCase):
              }
         )
         self.assertFalse(r)
+
+        # check for failcounter
+        tok.set_failcount(8)
+        r = uhandler.check_condition(
+            {"g": {},
+             "handler_def": {"conditions": {CONDITION.FAILCOUNTER: "<9"}},
+             "request": req,
+             "response": resp
+             }
+        )
+        self.assertTrue(r)
+
+        r = uhandler.check_condition(
+            {"g": {},
+             "handler_def": {"conditions": {CONDITION.FAILCOUNTER: ">9"}},
+             "request": req,
+             "response": resp
+             }
+        )
+        self.assertFalse(r)
+
+        r = uhandler.check_condition(
+            {"g": {},
+             "handler_def": {"conditions": {CONDITION.FAILCOUNTER: "=8"}},
+             "request": req,
+             "response": resp
+             }
+        )
+        self.assertTrue(r)
+
         remove_token(serial)
 
     def test_04_tokeninfo_condition(self):
@@ -523,6 +555,76 @@ class BaseEventHandlerTestCase(MyTestCase):
 
         remove_token(serial)
 
+    def test_08_counter_condition(self):
+        # increase a counter to 4
+        for i in range(0, 4):
+            counter_increase("myCounter")
+
+        uhandler = BaseEventHandler()
+        builder = EnvironBuilder(method='POST',
+                                 data={'user': "cornelius@realm1",
+                                       "pass": "secret"},
+                                 headers={})
+        env = builder.get_environ()
+        req = Request(env)
+        # This is a kind of authentication request
+        req.all_data = {"user": "cornelius@realm1",
+                        "pass": "secret"}
+        req.User = User("cornelius", "realm1")
+        resp = Response()
+        resp.data = """{"result": {"value": true}}"""
+
+        r = uhandler.check_condition(
+            {"g": {},
+             "handler_def": {"conditions": {CONDITION.COUNTER:
+                                                "myCounter<4"}},
+             "request": req,
+             "response": resp
+             }
+        )
+        self.assertFalse(r)
+
+        r = uhandler.check_condition(
+            {"g": {},
+             "handler_def": {"conditions": {CONDITION.COUNTER:
+                                                "myCounter==4"}},
+             "request": req,
+             "response": resp
+             }
+        )
+        self.assertTrue(r)
+
+        r = uhandler.check_condition(
+            {"g": {},
+             "handler_def": {"conditions": {CONDITION.COUNTER:
+                                                "myCounter>3"}},
+             "request": req,
+             "response": resp
+             }
+        )
+        self.assertTrue(r)
+
+        # If we have a nonexisting counter this should be treated as zero
+        r = uhandler.check_condition(
+            {"g": {},
+             "handler_def": {"conditions": {CONDITION.COUNTER:
+                                                "myNonExistingCounter>3"}},
+             "request": req,
+             "response": resp
+             }
+        )
+        self.assertFalse(r)
+
+        r = uhandler.check_condition(
+            {"g": {},
+             "handler_def": {"conditions": {CONDITION.COUNTER:
+                                                "myNonExistingCounter<3"}},
+             "request": req,
+             "response": resp
+             }
+        )
+        self.assertTrue(r)
+
 
 class CounterEventTestCase(MyTestCase):
 
@@ -669,6 +771,57 @@ class ScriptEventTestCase(MyTestCase):
         t_handler = ScriptEventHandler(script_directory=d)
         self.assertRaises(Exception, t_handler.do, script_name, options=options)
 
+    def test_03_sync_to_db(self):
+        g = FakeFlaskG()
+        g.logged_in_user = {"username": "admin",
+                            "role": "admin",
+                            "realm": ""}
+
+        builder = EnvironBuilder(method='POST',
+                                 data={'serial': "SPASS01"},
+                                 headers={})
+
+        req = Request(builder.get_environ())
+        req.all_data = {"serial": "SPASS01", "type": "spass"}
+        req.User = User()
+        resp = Response()
+        resp.data = """{"result": {"value": true}}"""
+
+        options = {"g": g,
+                   "request": req,
+                   "response": resp,
+                   "handler_def": {
+                       "options": {
+                           "user": "1",
+                           "realm": "1",
+                           "serial": "1",
+                           "logged_in_user": "1",
+                           "logged_in_role": "1"}
+                   }
+                   }
+
+        script_name = "ls.sh"
+        d = os.getcwd()
+        d = "{0!s}/tests/testdata/scripts/".format(d)
+        t_handler = ScriptEventHandler(script_directory=d)
+        # first check that the db session is not synced by default
+        with mock.patch('privacyidea.lib.eventhandler.scripthandler.db') as mdb:
+            res = t_handler.do(script_name, options=options)
+            mdb.session.commit.assert_not_called()
+        self.assertTrue(res)
+        # now set the parameter to sync the db session before running the script
+        options['handler_def']['options']['sync_to_database'] = "1"
+        with mock.patch('privacyidea.lib.eventhandler.scripthandler.db') as mdb:
+            res = t_handler.do(script_name, options=options)
+            mdb.session.commit.assert_called_with()
+        self.assertTrue(res)
+        # and now with the parameter explicitly disabled
+        options['handler_def']['options']['sync_to_database'] = "0"
+        with mock.patch('privacyidea.lib.eventhandler.scripthandler.db') as mdb:
+            res = t_handler.do(script_name, options=options)
+            mdb.session.commit.assert_not_called()
+        self.assertTrue(res)
+
 
 class FederationEventTestCase(MyTestCase):
 
